@@ -22,6 +22,7 @@ class Parser:
         'ARRAY': lambda args: exp.Array(expressions=args),
         'COLLECT_LIST': lambda args: exp.ArrayAgg(this=args[0]),
         'ARRAY_AGG': lambda args: exp.ArrayAgg(this=args[0]),
+        'ARRAY_CONTAINS': lambda args: exp.ArrayContains(this=args[0], value=args[1]),
         'DATE_ADD': lambda args: exp.DateAdd(this=args[0], value=args[1]),
         'DATE_DIFF': lambda args: exp.DateDiff(this=args[0], value=args[1]),
         'DATE_STR_TO_DATE': lambda args: exp.DateStrToDate(this=args[0]),
@@ -466,15 +467,15 @@ class Parser:
         if self._match(TokenType.IN):
             if not self._match(TokenType.L_PAREN):
                 self.raise_error('Expected ( after IN', self._prev)
-            expressions = self._parse_csv(self._parse_primary)
+            expressions = self._parse_csv(self._parse_term)
             if not self._match(TokenType.R_PAREN):
                 self.raise_error('Expected ) after IN')
             return exp.In(this=this, expressions=expressions)
 
         if self._match(TokenType.BETWEEN):
-            low = self._parse_primary()
+            low = self._parse_term()
             self._match(TokenType.AND)
-            high = self._parse_primary()
+            high = self._parse_term()
             return exp.Between(this=this, low=low, high=high)
 
         return this
